@@ -6,19 +6,159 @@ Container, Well, WellGroup objects and associated functions
     :license: BSD, see LICENSE for more details
 
 """
-
 import json
 import warnings
 
+from typing import Dict
+
+from autoprotocol.util import parse_unit
+
 from .constants import SBS_FORMAT_SHAPES
-from .unit import Unit
+from .unit import Unit, UnitError
 
 
 SEAL_TYPES = ["ultra-clear", "foil", "breathable"]
 COVER_TYPES = ["standard", "low_evaporation", "universal"]
 
 
-class Well(object):
+class EntityPropertiesMixin:
+    """
+    The mixin for Container and Well entities used to mutate the entity instance
+     ctx_properties and properties
+    """
+
+    @classmethod
+    def validate_properties(cls, properties):
+        """Validates that properties are valid"""
+        entity = cls.__name__
+        if not isinstance(properties, dict):
+            raise TypeError(
+                f"{str(entity)} properties {properties} are of type "
+                f"{type(properties)}, they should be a `dict`."
+            )
+        for key, value in properties.items():
+            if not isinstance(key, str):
+                raise TypeError(
+                    f"{str(entity)} property {key} : {value} has a key of type "
+                    f"{type(key)}, it should be a 'str'."
+                )
+            try:
+                json.dumps(value)
+            except TypeError:
+                raise TypeError(
+                    f"{str(entity)} property {key} : {value} has a value of type "
+                    f"{type(value)}, that isn't JSON serializable."
+                )
+
+    def set_properties(self, properties):
+        """
+        Set properties for an entity (ie: Container or Well). Existing property dictionary
+        will be completely overwritten with the new dictionary.
+
+        Parameters
+        ----------
+        properties : dict
+            Custom properties for an entity in dictionary form.
+
+        Returns
+        -------
+        self
+            Container or Well with modified properties
+        """
+        self.validate_properties(properties)
+        self.properties = properties.copy()
+        return self
+
+    def add_properties(self, properties):
+        """
+        Add properties to the properties attribute of an entity (ie: Container or Well).
+
+        If any property with the same key already exists for the entity then:
+         - if both old and new properties are lists then append the new property
+         - otherwise overwrite the old property with the new one
+
+        Parameters
+        ----------
+        properties : dict
+            Dictionary of properties to add to a entity.
+
+        Returns
+        -------
+        self
+            Container or Well with modified properties
+        """
+        self.validate_properties(properties)
+        for key, new_value in properties.items():
+            current_value = self.properties.get(key)
+            if key in self.properties:
+                if isinstance(current_value, list) and isinstance(new_value, list):
+                    current_value.extend(new_value)
+                else:
+                    message = f"Overwriting existing property {key} for {self}"
+                    warnings.warn(message=message)
+                    self.properties[key] = new_value
+            else:
+                self.properties[key] = new_value
+        return self
+
+    def set_ctx_properties(self, dict_: Dict):
+        """
+        Sets custom_contextual_properties for an entity (ie: Container or Well).
+        Existing property dictionary will be completely overwritten with the new dictionary.
+
+        Parameters
+        ----------
+        dict_ : dict
+            Custom custom_contextual_properties for an entity in dictionary form.
+
+        Raises
+        ------
+        TypeError
+            If dict_ is not of type dict
+
+        Returns
+        -------
+        self
+            Container or Well with modified custom_contextual_properties
+        """
+        self.validate_properties(dict_)
+        self.ctx_properties = dict_
+        return self
+
+    def add_ctx_properties(self, dict_: Dict):
+        """
+        Add properties to the custom_contextual_properties attribute of an entity (ie: Container or Well).
+
+        If any custom_contextual_properties with the same key already exists for the entity then:
+         - if both old and new properties are lists then append the new property
+         - otherwise overwrite the old property with the new one
+
+        Parameters
+        ----------
+        dict_ : dict
+            Dictionary of properties to add to a entity.
+
+        Returns
+        -------
+        self
+            Container or Well with modified custom_contextual_properties
+        """
+        self.validate_properties(dict_)
+        for key, new_value in dict_.items():
+            current_value = self.ctx_properties.get(key)
+            if current_value:
+                if isinstance(current_value, list) and isinstance(new_value, list):
+                    current_value.extend(new_value)
+                else:
+                    message = f"Overwriting existing property {key} for {self}"
+                    warnings.warn(message=message)
+                    self.ctx_properties[key] = new_value
+            else:
+                self.ctx_properties[key] = new_value
+        return self
+
+
+class Well(EntityPropertiesMixin):
     """
     A Well object describes a single location within a container.
 
@@ -31,88 +171,57 @@ class Well(object):
         The Container this well belongs to.
     index : int
         The index of this well within the container.
+    properties : dict, optional
+        mapping of key value properties associated to the Container
+    ctx_properties : dict, optional
+        mapping of key value properties associated to the Container
 
     """
 
-    def __init__(self, container, index):
+    def __init__(self, container, index, properties=None, ctx_properties=None):
         self.container = container
-        self.index = index
+        self.index = int(index)
         self.volume = None
+        self.mass = None
         self.name = None
-        self.properties = {}
+        self.compounds = None
+        self.properties = properties if isinstance(properties, dict) else dict()
+        self.ctx_properties = (
+            ctx_properties if isinstance(ctx_properties, dict) else dict()
+        )
 
-    @staticmethod
-    def validate_properties(properties):
-        if not isinstance(properties, dict):
+    def set_mass(self, mass):
+        """
+        Set the theoretical mass of contents in a Well.
+
+        Parameters
+        ----------
+        mass : str, Unit
+            Theoretical mass to indicate for a Well.
+
+        Returns
+        -------
+        Well
+            Well with modified mass
+
+        Raises
+        ------
+        TypeError
+            Incorrect input-type given
+        """
+        if mass is None:
+            # Set mass as None if no mass is known, as this is different from a mass of 0:mg
+            self.mass = None
+            return self
+
+        if not isinstance(mass, str) and not isinstance(mass, Unit):
             raise TypeError(
-                f"Aliquot properties {properties} are of type "
-                f"{type(properties)}, they should be a `dict`."
+                f"Mass {mass} is of type {type(mass)}, it should be either "
+                f"'str' or 'Unit'."
             )
-        for key, value in properties.items():
-            if not isinstance(key, str):
-                raise TypeError(
-                    f"Aliquot property {key} : {value} has a key of type "
-                    f"{type(key)}, it should be a 'str'."
-                )
-            try:
-                json.dumps(value)
-            except TypeError:
-                raise TypeError(
-                    f"Aliquot property {key} : {value} has a value of type "
-                    f"{type(value)}, that isn't JSON serializable."
-                )
+        m = parse_unit(mass)
+        self.mass = m
 
-    def set_properties(self, properties):
-        """
-        Set properties for a Well. Existing property dictionary
-        will be completely overwritten with the new dictionary.
-
-        Parameters
-        ----------
-        properties : dict
-            Custom properties for a Well in dictionary form.
-
-        Returns
-        -------
-        Well
-            Well with modified properties
-        """
-        self.validate_properties(properties)
-        self.properties = properties.copy()
-        return self
-
-    def add_properties(self, properties):
-        """
-        Add properties to the properties attribute of a Well.
-
-        If any property with the same key already exists for the Well then:
-         - if both old and new properties are lists then append the new property
-         - otherwise overwrite the old property with the new one
-
-        Parameters
-        ----------
-        properties : dict
-            Dictionary of properties to add to a Well.
-
-        Returns
-        -------
-        Well
-            Well with modified properties
-        """
-        self.validate_properties(properties)
-        for key, value in properties.items():
-            if key in self.properties:
-                values_are_lists = all(
-                    isinstance(_, list) for _ in [value, self.properties[key]]
-                )
-                if values_are_lists:
-                    self.properties[key].extend(value)
-                else:
-                    message = f"Overwriting existing property {key} for {self}"
-                    warnings.warn(message=message)
-                    self.properties[key] = value
-            else:
-                self.properties[key] = value
         return self
 
     def set_volume(self, vol):
@@ -151,6 +260,101 @@ class Well(object):
         self.volume = v
         return self
 
+    def set_compounds(self, compounds):
+        """
+        Sets the list of associated compounds, and their metadata, to an aliquot.
+
+        Parameters
+        ----------
+        compounds : list
+            List of compounds associated to a well.
+
+        Returns
+        -------
+        Well
+            Well with associated compounds
+
+        Raises
+        ------
+        TypeError
+            Incorrect input-type given
+        """
+        # expected parameters and label transformations
+        expected_params = {
+            "id": "id",
+            "molecularWeight": "molecular_weight",
+            "smiles": "smiles",
+            "concentration": "concentration",
+            "solubilityFlag": "solubility_flag",
+        }
+        if not isinstance(compounds, list):
+            raise TypeError(
+                f"Compound list {compounds} is of type {type(compounds)}, it should be a 'list'."
+            )
+
+        for compound in compounds:
+            if isinstance(compound, dict):
+                for k in expected_params:
+                    if k in compound:
+                        # transform {"molecularWeight": float} -> {"molecular_weight": Unit}
+                        if k == "molecularWeight":
+                            try:
+                                mw = Unit(compound.pop(k), "g/mol")
+                            except (UnitError):
+                                mw = None
+                            compound[expected_params[k]] = mw
+                        elif k == "solubilityFlag":
+                            compound[expected_params[k]] = compound.pop(k)
+                        elif k == "concentration":
+                            try:
+                                conc = Unit(compound.pop(k), "millimol/liter")
+                            except (UnitError):
+                                conc = None
+                            compound[expected_params[k]] = conc
+                        elif k == "smiles":
+                            # TODO: validation on smiles
+                            pass
+                        else:
+                            pass
+                    else:
+                        # set unspecified keys using preferred param string
+                        compound[expected_params[k]] = None
+            else:
+                pass
+
+        self.compounds = compounds
+        return self
+
+    def add_volume(self, vol: Unit):
+        """
+        Updates the volume of the well
+
+        Parameters
+        ----------
+        vol : str, Unit
+            Theoretical volume to indicate for a Well.
+
+        Returns
+        -------
+        Unit
+            the updated volume of the Well
+
+        Raises
+        ------
+        TypeError
+            Error when input does not match expected type or dimensionality
+        ValueError
+            Volume set exceeds maximum well volume
+        """
+
+        v = parse_unit(vol)
+
+        if self.volume:
+            self.volume += v
+        else:
+            self.volume = v
+        return self.volume
+
     def set_name(self, name):
         """
         Set a name for this well for it to be included in a protocol's
@@ -561,7 +765,7 @@ class WellGroup(object):
 
 
 # pylint: disable=redefined-builtin
-class Container(object):
+class Container(EntityPropertiesMixin):
     """
     A reference to a specific physical container (e.g. a tube or 96-well
     microplate).
@@ -587,6 +791,10 @@ class Container(object):
         name of the storage condition.
     cover : str, optional
         name of the cover on the container.
+    properties : dict, optional
+        mapping of key value properties associated to the Container
+    ctx_properties : dict, optional
+        mapping of key value properties associated to the Container
 
     Raises
     ------
@@ -595,12 +803,25 @@ class Container(object):
 
     """
 
-    def __init__(self, id, container_type, name=None, storage=None, cover=None):
+    def __init__(
+        self,
+        id,
+        container_type,
+        name=None,
+        storage=None,
+        cover=None,
+        properties=None,
+        ctx_properties=None,
+    ):
         self.name = name
         self.id = id
         self.container_type = container_type
         self.storage = storage
         self.cover = cover
+        self.properties = properties if isinstance(properties, dict) else dict()
+        self.ctx_properties = (
+            ctx_properties if isinstance(ctx_properties, dict) else dict()
+        )
         self._wells = [Well(self, idx) for idx in range(container_type.well_count)]
         if self.cover and not (self.is_covered() or self.is_sealed()):
             raise AttributeError(f"{cover} is not a valid seal or cover type.")
