@@ -6,7 +6,6 @@ Container-type object and associated functions
     :license: BSD, see LICENSE for more details
 
 """
-
 import re
 
 from collections import namedtuple
@@ -503,7 +502,7 @@ FLAT384WHITETC = ContainerType(
     sterile=True,
     is_tube=False,
     cover_types=["standard", "universal"],
-    seal_types=None,
+    seal_types=["ultra-clear", "foil"],
     capabilities=[
         "absorbance",
         "cover",
@@ -515,6 +514,7 @@ FLAT384WHITETC = ContainerType(
         "liquid_handle",
         "spin",
         "uncover",
+        "seal",
     ],
     shortname="384-flat-white-white-tc",
     col_count=24,
@@ -1071,6 +1071,42 @@ ROUND384CLEAR = ContainerType(
     cat_no="3657",
 )
 
+#:
+ROUND384LV = ContainerType(
+    name="384-well round-bottom low-volume non-binding-surface Corning-4513 plate",
+    well_count=384,
+    well_depth_mm=6.58,
+    well_volume_ul=Unit(20.0, "microliter"),
+    well_coating="nonbinding_surface",
+    sterile=False,
+    is_tube=False,
+    cover_types=["universal", "standard"],
+    seal_types=["ultra-clear", "foil"],
+    capabilities=[
+        "incubate",
+        "seal",
+        "deseal",
+        "liquid_handle",
+        "dispense",
+        "spin",
+        "fluorescence",
+        "cover",
+        "uncover",
+        "echo_dest",
+        "stamp",
+        "transfer",
+        "provision",
+        "pipette",
+        "envision",
+    ],
+    shortname="384-corning-4513-round-lv",
+    col_count=24,
+    dead_volume_ul=Unit(2, "microliter"),
+    safe_min_volume_ul=Unit(2, "microliter"),
+    vendor="Corning",
+    cat_no="4513",
+)
+
 #:
 RESSW384LP = ContainerType(
     name="384-well singlewell lowprofile reservoir",
@@ -1082,7 +1118,14 @@ RESSW384LP = ContainerType(
     is_tube=False,
     cover_types=["universal"],
     seal_types=None,
-    capabilities=["liquid_handle", "incubate", "cover", "dispense", "liquid_handle"],
+    capabilities=[
+        "liquid_handle",
+        "incubate",
+        "cover",
+        "dispense",
+        "liquid_handle",
+        "sbs384_compatible",
+    ],
     shortname="res-sw384-lp",
     col_count=1,
     dead_volume_ul=Unit(10, "milliliter"),
@@ -1134,6 +1177,28 @@ ECHO384LDVPLUS = ContainerType(
     cat_no="LPL-0200",
 )
 
+#:
+ECHO1536LDV = ContainerType(
+    # Compatible with Labcyte Echo 550, 555 and 650
+    name="1536-well Echo low dead volume Beckman-001-6969 plate",
+    well_count=1536,
+    well_depth_mm=5.15,
+    well_volume_ul=Unit(5.5, "microliter"),
+    well_coating=None,
+    sterile=None,
+    is_tube=False,
+    cover_types=["universal"],
+    seal_types=["foil", "ultra-clear"],
+    capabilities=["liquid_handle", "seal", "spin", "incubate", "dispense", "cover"],
+    shortname="1536-echo-ldv-beckman-001-6969",
+    col_count=48,
+    dead_volume_ul=Unit(1, "microliter"),
+    safe_min_volume_ul=Unit(1, "microliter"),
+    true_max_vol_ul=Unit(5.5, "microliter"),
+    vendor="Beckman",
+    cat_no="001-6969",
+)
+
 #:
 FLAT384WHITECLEAR = ContainerType(
     name="384-well flat-bottom polystyrene plate",
@@ -1191,7 +1256,7 @@ FALCON96UBOTTOM = ContainerType(
         "seal",
         "unseal",
     ],
-    cover_types=["low_evaporation", "standard", "universal"],
+    cover_types=["universal"],
     seal_types=["ultra-clear", "foil"],
     vendor="Corning",
     cat_no="353077",
@@ -1232,6 +1297,114 @@ FLAT96DELTA = ContainerType(
     cat_no="136101",
 )
 
+#:
+FLAT384BLACKUBOTTOM = ContainerType(
+    name="384-well Black Clear Round Bottom Ultra-low Attachment Microplate",
+    shortname="384-ubottom-black-clear-tc",
+    is_tube=False,
+    well_coating=None,
+    sterile=True,
+    well_count=384,
+    col_count=24,
+    well_depth_mm=12.55,
+    well_volume_ul=Unit(90, "microliter"),
+    dead_volume_ul=Unit(10, "microliter"),
+    safe_min_volume_ul=Unit(20, "microliter"),
+    capabilities=[
+        "pipette",
+        "spin",
+        "incubate",
+        "cover",
+        "stamp",
+        "dispense",
+        "dispense-destination",
+        "echo_dest",
+        "provision",
+        "uncover",
+        "seal",
+        "unseal",
+        "liquid_handle",
+        "absorbance",
+        "fluorescence",
+        "luminescence",
+        "bluewash",
+        "spectophotometry",
+    ],
+    cover_types=["universal"],
+    seal_types=["ultra-clear", "foil"],
+    vendor="Corning",
+    cat_no="3830",
+)
+
+#:
+FLAT384BLACKTC = ContainerType(
+    name="384-well Black Clear Flat Bottom Tissue Culture Microplate",
+    shortname="384-flatbottom-black-clear-tc",
+    is_tube=False,
+    well_coating=None,
+    sterile=True,
+    well_count=384,
+    col_count=24,
+    well_depth_mm=11.55,
+    well_volume_ul=Unit(90, "microliter"),
+    dead_volume_ul=Unit(20, "microliter"),
+    safe_min_volume_ul=Unit(20, "microliter"),
+    capabilities=[
+        "pipette",
+        "spin",
+        "incubate",
+        "cover",
+        "stamp",
+        "dispense",
+        "dispense-destination",
+        "echo_dest",
+        "provision",
+        "uncover",
+        "seal",
+        "unseal",
+        "liquid_handle",
+        "absorbance",
+        "fluorescence",
+        "luminescence",
+        "bluewash",
+        "spectophotometry",
+    ],
+    cover_types=["universal", "standard"],
+    seal_types=["ultra-clear", "foil"],
+    vendor="Corning",
+    cat_no="3764",
+)
+
+#:
+PCR96FSC = ContainerType(
+    name="96-well Polypropylene PCR Microplate, Full Skirt, Clear, Nonsterile",
+    well_count=96,
+    well_depth_mm=14.6,
+    well_volume_ul=Unit(200.0, "microliter"),
+    well_coating=None,
+    sterile=False,
+    is_tube=False,
+    cover_types=None,
+    seal_types=["ultra-clear", "foil"],
+    capabilities=[
+        "liquid_handle",
+        "sangerseq",
+        "spin",
+        "thermocycle",
+        "incubate",
+        "gel_separate",
+        "gel_purify",
+        "seal",
+        "dispense",
+    ],
+    shortname="96-pcr-fs-clear",
+    col_count=12,
+    dead_volume_ul=Unit(3, "microliter"),
+    safe_min_volume_ul=Unit(5, "microliter"),
+    vendor="Axygen",
+    cat_no="PCR-96-FS-C",
+)
+
 _CONTAINER_TYPES = {
     "384-flat": FLAT384,
     "384-pcr": PCR384,
@@ -1258,10 +1431,15 @@ _CONTAINER_TYPES = {
     "384-v-clear-clear": V384CLEAR,
     "384-round-clear-clear": ROUND384CLEAR,
     "res-sw384-lp": RESSW384LP,
+    "384-corning-4513-round-lv": ROUND384LV,
     "384-echo-ldv": ECHO384LDV,
     "384-echo-ldv-plus": ECHO384LDVPLUS,
+    "1536-echo-ldv-beckman-001-6969": ECHO1536LDV,
     "384-flat-white-clear": FLAT384WHITECLEAR,
     "96-well-v-bottom": V96CC,
     "96-ubottom-clear-tc": FALCON96UBOTTOM,
     "96-flat-white-dc": FLAT96DELTA,
+    "384-ubottom-black-clear-tc": FLAT384BLACKUBOTTOM,
+    "384-flatbottom-black-clear-tc": FLAT384BLACKTC,
+    "96-pcr-fs-clear": PCR96FSC,
 }
